@@ -557,11 +557,12 @@ class HTTPSClientCertTransport(HttpTransport):
                  client_keyfile=None, client_certfile=None,
                  client_keyobj=None, client_certobj=None,
                  cookie_callback=None, user_agent_string=None,
-                 wait_thread=None, **kwargs):
+                 wait_thread=None, rsa_password=None, **kwargs):
         Transport.__init__(self)
         self.key = key
         self.cert = cert
         self.cert_path = path_to_cert
+        self.rsa_password = rsa_password or b""
         if key:
             with open(cert) as cert_file:
                 client_certobj = OpenSSL.crypto.load_certificate \
@@ -574,12 +575,12 @@ class HTTPSClientCertTransport(HttpTransport):
                 else:
                     import M2Crypto
                     bio = M2Crypto.BIO.openfile(key)
-                    rsa = M2Crypto.m2.rsa_read_key(bio._ptr(),lambda *unused: b"")
+                    rsa = M2Crypto.m2.rsa_read_key(bio._ptr(),lambda *unused: self.rsa_password)
                     if not rsa:
                         raise OpenSSL.crypto.Error
                     with open(key) as key_file:
                         client_keyobj = OpenSSL.crypto.load_privatekey(OpenSSL.SSL.FILETYPE_PEM, 
-                            key_file.read())
+                            key_file.read(), passphrase=self.rsa_password or None)
 
         Unskin(self.options).update(kwargs)
         self.cookiejar = CookieJar(DefaultCookiePolicy())
